@@ -555,6 +555,7 @@ struct activity disk_act = {
 	.f_json_print	= json_print_disk_stats,
 	.f_svg_print	= svg_print_disk_stats,
 	.f_raw_print	= raw_print_disk_stats,
+	.f_pcp_print	= pcp_print_disk_stats,
 	.f_count_new	= count_new_disk,
 	.item_list	= NULL,
 	.desc		= "Block devices statistics",
@@ -1483,6 +1484,7 @@ struct activity pwr_fan_act = {
 	.f_json_print	= json_print_pwr_fan_stats,
 	.f_svg_print	= svg_print_pwr_fan_stats,
 	.f_raw_print	= raw_print_pwr_fan_stats,
+	.f_pcp_print	= pcp_print_pwr_fan_stats,
 	.f_count_new	= NULL,
 	.item_list	= NULL,
 	.desc		= "Fans speed",
@@ -1528,6 +1530,7 @@ struct activity pwr_temp_act = {
 	.f_json_print	= json_print_pwr_temp_stats,
 	.f_svg_print	= svg_print_pwr_temp_stats,
 	.f_raw_print	= raw_print_pwr_temp_stats,
+	.f_pcp_print	= pcp_print_pwr_temp_stats,
 	.f_count_new	= NULL,
 	.item_list	= NULL,
 	.desc		= "Devices temperature",
@@ -1573,6 +1576,7 @@ struct activity pwr_in_act = {
 	.f_json_print	= json_print_pwr_in_stats,
 	.f_svg_print	= svg_print_pwr_in_stats,
 	.f_raw_print	= raw_print_pwr_in_stats,
+	.f_pcp_print	= pcp_print_pwr_in_stats,
 	.f_count_new	= NULL,
 	.item_list	= NULL,
 	.desc		= "Voltage inputs statistics",
@@ -1618,6 +1622,7 @@ struct activity huge_act = {
 	.f_json_print	= json_print_huge_stats,
 	.f_svg_print	= svg_print_huge_stats,
 	.f_raw_print	= raw_print_huge_stats,
+	.f_pcp_print	= pcp_print_huge_stats,
 	.f_count_new	= NULL,
 	.item_list	= NULL,
 	.desc		= "Huge pages utilization",
@@ -1708,6 +1713,7 @@ struct activity pwr_usb_act = {
 	.f_json_print	= json_print_pwr_usb_stats,
 	.f_svg_print	= NULL,
 	.f_raw_print	= raw_print_pwr_usb_stats,
+	.f_pcp_print	= pcp_print_pwr_usb_stats,
 	.f_count_new	= NULL,
 	.item_list	= NULL,
 	.desc		= "USB devices",
@@ -1754,6 +1760,7 @@ struct activity filesystem_act = {
 	.f_json_print	= json_print_filesystem_stats,
 	.f_svg_print	= svg_print_filesystem_stats,
 	.f_raw_print	= raw_print_filesystem_stats,
+	.f_pcp_print	= pcp_print_filesystem_stats,
 	.f_count_new	= count_new_filesystem,
 	.item_list	= NULL,
 	.desc		= "Filesystems statistics",
@@ -1799,6 +1806,7 @@ struct activity fchost_act = {
 	.f_json_print	= json_print_fchost_stats,
 	.f_svg_print	= svg_print_fchost_stats,
 	.f_raw_print	= raw_print_fchost_stats,
+	.f_pcp_print	= pcp_print_fchost_stats,
 	.f_count_new	= count_new_fchost,
 	.item_list	= NULL,
 	.desc		= "Fibre Channel HBA statistics",
