@@ -463,8 +463,8 @@ __nr_t get_usb_nr(void)
 __nr_t get_filesystem_nr(void)
 {
 	FILE *fp;
-	char line[512], fs_name[MAX_FS_LEN], mountp[256];
-	char *pos = 0;
+	char line[512], fs_name[MAX_FS_LEN], mountp[256], type[128];
+	char *pos = 0, *pos2 = 0;
 	__nr_t fs = 0;
 	int skip = 0, skip_next = 0;
 	struct statvfs buf;
@@ -491,6 +491,19 @@ __nr_t get_filesystem_nr(void)
 			if (pos == NULL)
 				continue;
 
+			/*
+			 * Find second field separator position,
+			 * read filesystem type,
+			 * if filesystem type is autofs, skip it
+			*/
+			pos2 = strchr(pos + 1, ' ');
+			if (pos2 == NULL)
+				continue;
+
+			sscanf(pos2 + 1, "%127s", type);
+			if(strcmp(type, "autofs") == 0)
+				continue;
+
 			/* Read filesystem name and mount point */
 			sscanf(line, "%127s", fs_name);
 			sscanf(pos + 1, "%255s", mountp);
@@ -499,7 +512,7 @@ __nr_t get_filesystem_nr(void)
 			oct2chr(mountp);
 
 			/* Check that total size is not zero */
-			if (statvfs(mountp, &buf) < 0)
+			if (__statvfs(mountp, &buf) < 0)
 				continue;
 
 			if (buf.f_blocks) {
