@@ -52,6 +52,10 @@
 char *sccsid(void) { return (SCCSID); }
 #endif
 
+#ifdef TEST
+extern int __env;
+#endif
+
 struct stats_cpu *st_cpu[2];
 unsigned long long uptime_cs[2] = {0, 0};
 unsigned long long tot_jiffies[2] = {0, 0};
@@ -1849,9 +1853,6 @@ int main(int argc, char **argv)
 	init_nls();
 #endif
 
-	/* Init color strings */
-	init_colors();
-
 	/* Process args... */
 	while (opt < argc) {
 
@@ -1905,6 +1906,13 @@ int main(int argc, char **argv)
 			opt++;
 		}
 
+#ifdef TEST
+		else if (!strncmp(argv[opt], "--getenv", 8)) {
+			__env = TRUE;
+			opt++;
+		}
+#endif
+
 		else if (!strncmp(argv[opt], "--dec=", 6) && (strlen(argv[opt]) == 7)) {
 			/* Get number of decimal places */
 			dplaces_nr = atoi(argv[opt] + 6);
@@ -2098,6 +2106,9 @@ int main(int argc, char **argv)
 		count = 1;
 	}
 
+	/* Init color strings */
+	init_colors();
+
 	/* Default: Display CPU and DISK reports */
 	if (!report_set) {
 		flags |= I_D_CPU + I_D_DISK;
