@@ -734,7 +734,8 @@ __print_funct_t json_print_disk_stats(struct activity *a, int curr, int tab,
 		}
 
 		/* Get device name */
-		dev_name = get_sa_devname(sdc->major, sdc->minor, flags);
+		dev_name = get_sa_devname(sdc->major, sdc->minor,
+					  sdc->wwn, sdc->part_nr, flags);
 
 		if (a->item_list != NULL) {
 			/* A list of devices has been entered on the command line */
@@ -2237,12 +2238,14 @@ __print_funct_t json_print_fchost_stats(struct activity *a, int curr, int tab,
 					unsigned long long itv)
 {
 	int i, j, j0, found;
-	struct stats_fchost *sfcc, *sfcp;
+	struct stats_fchost *sfcc, *sfcp, sfczero;
 	int sep = FALSE;
 
 	if (!IS_SELECTED(a->options) || (a->nr[curr] <= 0))
 		goto close_json_markup;
 
+	memset(&sfczero, 0, sizeof(struct stats_fchost));
+
 	json_markup_network(tab, OPEN_JSON_MARKUP);
 	tab++;
 
@@ -2251,10 +2254,9 @@ __print_funct_t json_print_fchost_stats(struct activity *a, int curr, int tab,
 	for (i = 0; i < a->nr[curr]; i++) {
 
 		found = FALSE;
+		sfcc = (struct stats_fchost *) ((char *) a->buf[curr] + i * a->msize);
 
 		if (a->nr[!curr] > 0) {
-			sfcc = (struct stats_fchost *) ((char *) a->buf[curr] + i * a->msize);
-
 			/* Look for corresponding structure in previous iteration */
 			j = i;
 
@@ -2277,8 +2279,10 @@ __print_funct_t json_print_fchost_stats(struct activity *a, int curr, int tab,
 			while (j != j0);
 		}
 
-		if (!found)
-			continue;
+		if (!found) {
+			/* This is a newly registered host */
+			sfcp = &sfczero;
+		}
 
 		if (sep)
 			printf(",\n");
