@@ -14,7 +14,7 @@
  ***************************************************************************
  */
 
-/* Functions used to display statistics in XML */
+/* Functions used to display statistics in JSON */
 __print_funct_t json_print_cpu_stats
 	(struct activity *, int, int, unsigned long long);
 __print_funct_t json_print_pcsw_stats
@@ -94,4 +94,4 @@ __print_funct_t json_print_fchost_stats
 __print_funct_t json_print_softnet_stats
 	(struct activity *, int, int, unsigned long long);
 
-#endif /* _XML_STATS_H */
+#endif /* _JSON_STATS_H */
