@@ -25,8 +25,10 @@
 
 #ifdef HAVE_PCP
 #include <pcp/pmapi.h>
-#include <pcp/impl.h>
 #include <pcp/import.h>
+#ifdef HAVE_PCP_IMPL_H
+#include <pcp/impl.h>
+#endif
 #endif
 
 /*
@@ -369,15 +371,15 @@ void pcp_def_io_metrics(void)
 
 	pmiAddMetric("disk.all.read_bytes",
 		     PM_IN_NULL, PM_TYPE_FLOAT, PM_INDOM_NULL, PM_SEM_INSTANT,
-		     pmiUnits(1, -1, 1, PM_SPACE_KBYTE, PM_TIME_SEC, 0));
+		     pmiUnits(1, -1, 0, PM_SPACE_KBYTE, PM_TIME_SEC, 0));
 
 	pmiAddMetric("disk.all.write_bytes",
 		     PM_IN_NULL, PM_TYPE_FLOAT, PM_INDOM_NULL, PM_SEM_INSTANT,
-		     pmiUnits(1, -1, 1, PM_SPACE_KBYTE, PM_TIME_SEC, 0));
+		     pmiUnits(1, -1, 0, PM_SPACE_KBYTE, PM_TIME_SEC, 0));
 
 	pmiAddMetric("disk.all.discard_bytes",
 		     PM_IN_NULL, PM_TYPE_FLOAT, PM_INDOM_NULL, PM_SEM_INSTANT,
-		     pmiUnits(1, -1, 1, PM_SPACE_KBYTE, PM_TIME_SEC, 0));
+		     pmiUnits(1, -1, 0, PM_SPACE_KBYTE, PM_TIME_SEC, 0));
 #endif /* HAVE_PCP */
 }
 
@@ -396,15 +398,15 @@ void pcp_def_memory_metrics(struct activity *a)
 
 		pmiAddMetric("mem.util.free",
 			     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
-			     pmiUnits(1, 0, 0, 0, PM_SPACE_KBYTE, 0));
+			     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
 
 		pmiAddMetric("mem.util.available",
 			     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
-			     pmiUnits(1, 0, 0, 0, PM_SPACE_KBYTE, 0));
+			     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
 
 		pmiAddMetric("mem.util.used",
 			     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
-			     pmiUnits(1, 0, 0, 0, PM_SPACE_KBYTE, 0));
+			     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
 
 		pmiAddMetric("mem.util.used_pct",
 			     PM_IN_NULL, PM_TYPE_FLOAT, PM_INDOM_NULL, PM_SEM_INSTANT,
@@ -412,15 +414,15 @@ void pcp_def_memory_metrics(struct activity *a)
 
 		pmiAddMetric("mem.util.buffers",
 			     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
-			     pmiUnits(1, 0, 0, 0, PM_SPACE_KBYTE, 0));
+			     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
 
 		pmiAddMetric("mem.util.cached",
 			     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
-			     pmiUnits(1, 0, 0, 0, PM_SPACE_KBYTE, 0));
+			     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
 
 		pmiAddMetric("mem.util.commit",
 			     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
-			     pmiUnits(1, 0, 0, 0, PM_SPACE_KBYTE, 0));
+			     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
 
 		pmiAddMetric("mem.util.commit_pct",
 			     PM_IN_NULL, PM_TYPE_FLOAT, PM_INDOM_NULL, PM_SEM_INSTANT,
@@ -428,37 +430,37 @@ void pcp_def_memory_metrics(struct activity *a)
 
 		pmiAddMetric("mem.util.active",
 			     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
-			     pmiUnits(1, 0, 0, 0, PM_SPACE_KBYTE, 0));
+			     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
 
 		pmiAddMetric("mem.util.inactive",
 			     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
-			     pmiUnits(1, 0, 0, 0, PM_SPACE_KBYTE, 0));
+			     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
 
 		pmiAddMetric("mem.util.dirty",
 			     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
-			     pmiUnits(1, 0, 0, 0, PM_SPACE_KBYTE, 0));
+			     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
 
 		if (DISPLAY_MEM_ALL(a->opt_flags)) {
 
 			pmiAddMetric("mem.util.anonpages",
 				     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
-				     pmiUnits(1, 0, 0, 0, PM_SPACE_KBYTE, 0));
+				     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
 
 			pmiAddMetric("mem.util.slab",
 				     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
-				     pmiUnits(1, 0, 0, 0, PM_SPACE_KBYTE, 0));
+				     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
 
 			pmiAddMetric("mem.util.stack",
 				     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
-				     pmiUnits(1, 0, 0, 0, PM_SPACE_KBYTE, 0));
+				     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
 
 			pmiAddMetric("mem.util.pageTables",
 				     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
-				     pmiUnits(1, 0, 0, 0, PM_SPACE_KBYTE, 0));
+				     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
 
 			pmiAddMetric("mem.util.vmused",
 				     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
-				     pmiUnits(1, 0, 0, 0, PM_SPACE_KBYTE, 0));
+				     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
 		}
 	}
 
@@ -466,11 +468,11 @@ void pcp_def_memory_metrics(struct activity *a)
 
 		pmiAddMetric("mem.util.swapFree",
 			     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
-			     pmiUnits(1, 0, 0, 0, PM_SPACE_KBYTE, 0));
+			     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
 
 		pmiAddMetric("mem.util.swapUsed",
 			     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
-			     pmiUnits(1, 0, 0, 0, PM_SPACE_KBYTE, 0));
+			     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
 
 		pmiAddMetric("mem.util.swapUsed_pct",
 			     PM_IN_NULL, PM_TYPE_FLOAT, PM_INDOM_NULL, PM_SEM_INSTANT,
@@ -478,7 +480,7 @@ void pcp_def_memory_metrics(struct activity *a)
 
 		pmiAddMetric("mem.util.swapCached",
 			     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
-			     pmiUnits(1, 0, 0, 0, PM_SPACE_KBYTE, 0));
+			     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
 
 		pmiAddMetric("mem.util.swapCached_pct",
 			     PM_IN_NULL, PM_TYPE_FLOAT, PM_INDOM_NULL, PM_SEM_INSTANT,
@@ -545,6 +547,66 @@ void pcp_def_queue_metrics(void)
 #endif /* HAVE_PCP */
 }
 
+/*
+ ***************************************************************************
+ * Define PCP metrics for disks statistics.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ ***************************************************************************
+ */
+void pcp_def_disk_metrics(struct activity *a)
+{
+#ifdef HAVE_PCP
+	int inst = 0;
+	static pmInDom indom = PM_INDOM_NULL;
+	struct sa_item *list = a->item_list;
+
+	if (indom == PM_INDOM_NULL) {
+		/* Create domain */
+		indom = pmInDom_build(0, PM_INDOM_DISK);
+
+		/* Create instances */
+		while (list != NULL) {
+			pmiAddInstance(indom, list->item_name, inst++);
+			list = list->next;
+		}
+	}
+
+	pmiAddMetric("disk.device.tps",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, -1, 1, 0, PM_TIME_SEC, PM_COUNT_ONE));
+
+	pmiAddMetric("disk.device.read_bytes",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(1, -1, 0, PM_SPACE_KBYTE, PM_TIME_SEC, 0));
+
+	pmiAddMetric("disk.device.write_bytes",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(1, -1, 0, PM_SPACE_KBYTE, PM_TIME_SEC, 0));
+
+	pmiAddMetric("disk.device.discard_bytes",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(1, -1, 0, PM_SPACE_KBYTE, PM_TIME_SEC, 0));
+
+	pmiAddMetric("disk.device.areq_sz",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
+
+	pmiAddMetric("disk.device.aqu_sz",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+
+	pmiAddMetric("disk.device.await",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+
+	pmiAddMetric("disk.device.util",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+#endif /* HAVE_PCP */
+}
+
 /*
  ***************************************************************************
  * Define PCP metrics for network interfaces (errors) statistics.
@@ -1396,3 +1458,301 @@ void pcp_def_net_udp6_metrics(void)
 		     pmiUnits(0, -1, 1, 0, PM_TIME_SEC, PM_COUNT_ONE));
 #endif /* HAVE_PCP */
 }
+
+/*
+ ***************************************************************************
+ * Define PCP metrics for huge pages statistics.
+ ***************************************************************************
+ */
+void pcp_def_huge_metrics()
+{
+#ifdef HAVE_PCP
+	pmiAddMetric("mem.huge.free",
+		     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
+		     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
+
+	pmiAddMetric("mem.huge.used",
+		     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
+		     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
+
+	pmiAddMetric("mem.huge.used_pct",
+		     PM_IN_NULL, PM_TYPE_FLOAT, PM_INDOM_NULL, PM_SEM_INSTANT,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+
+	pmiAddMetric("mem.huge.reserved",
+		     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
+		     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
+
+	pmiAddMetric("mem.huge.surplus",
+		     PM_IN_NULL, PM_TYPE_U64, PM_INDOM_NULL, PM_SEM_INSTANT,
+		     pmiUnits(1, 0, 0, PM_SPACE_KBYTE, 0, 0));
+#endif /* HAVE_PCP */
+}
+
+/*
+ ***************************************************************************
+ * Define PCP metrics for fan statistics.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ ***************************************************************************
+ */
+void pcp_def_pwr_fan_metrics(struct activity *a)
+{
+#ifdef HAVE_PCP
+	int inst = 0;
+	static pmInDom indom = PM_INDOM_NULL;
+	char buf[16];
+
+	if (indom == PM_INDOM_NULL) {
+		/* Create domain */
+		indom = pmInDom_build(0, PM_INDOM_FAN);
+
+		for (inst = 0; inst < a->item_list_sz; inst++) {
+			sprintf(buf, "fan%d", inst + 1);
+			pmiAddInstance(indom, buf, inst);
+		}
+	}
+
+	pmiAddMetric("power.fan.rpm",
+		     PM_IN_NULL, PM_TYPE_U64, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+
+	pmiAddMetric("power.fan.drpm",
+		     PM_IN_NULL, PM_TYPE_U64, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+
+	pmiAddMetric("power.fan.device",
+		     PM_IN_NULL, PM_TYPE_STRING, indom, PM_SEM_DISCRETE,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+#endif /* HAVE_PCP */
+}
+
+/*
+ ***************************************************************************
+ * Define PCP metrics for temperature statistics.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ ***************************************************************************
+ */
+void pcp_def_pwr_temp_metrics(struct activity *a)
+{
+#ifdef HAVE_PCP
+	int inst = 0;
+	static pmInDom indom = PM_INDOM_NULL;
+	char buf[16];
+
+	if (indom == PM_INDOM_NULL) {
+		/* Create domain */
+		indom = pmInDom_build(0, PM_INDOM_TEMP);
+
+		for (inst = 0; inst < a->item_list_sz; inst++) {
+			sprintf(buf, "temp%d", inst + 1);
+			pmiAddInstance(indom, buf, inst);
+		}
+	}
+
+	pmiAddMetric("power.temp.degC",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+
+	pmiAddMetric("power.temp.temp_pct",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+
+	pmiAddMetric("power.temp.device",
+		     PM_IN_NULL, PM_TYPE_STRING, indom, PM_SEM_DISCRETE,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+#endif /* HAVE_PCP */
+}
+
+/*
+ ***************************************************************************
+ * Define PCP metrics for voltage inputs statistics.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ ***************************************************************************
+ */
+void pcp_def_pwr_in_metrics(struct activity *a)
+{
+#ifdef HAVE_PCP
+	int inst = 0;
+	static pmInDom indom = PM_INDOM_NULL;
+	char buf[16];
+
+	if (indom == PM_INDOM_NULL) {
+		/* Create domain */
+		indom = pmInDom_build(0, PM_INDOM_IN);
+
+		for (inst = 0; inst < a->item_list_sz; inst++) {
+			sprintf(buf, "in%d", inst);
+			pmiAddInstance(indom, buf, inst);
+		}
+	}
+
+	pmiAddMetric("power.in.inV",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+
+	pmiAddMetric("power.in.in_pct",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+
+	pmiAddMetric("power.in.device",
+		     PM_IN_NULL, PM_TYPE_STRING, indom, PM_SEM_DISCRETE,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+#endif /* HAVE_PCP */
+}
+
+/*
+ ***************************************************************************
+ * Define PCP metrics for USB devices statistics.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ ***************************************************************************
+ */
+void pcp_def_pwr_usb_metrics(struct activity *a)
+{
+#ifdef HAVE_PCP
+	int inst = 0;
+	static pmInDom indom = PM_INDOM_NULL;
+	char buf[16];
+
+	if (indom == PM_INDOM_NULL) {
+		/* Create domain */
+		indom = pmInDom_build(0, PM_INDOM_USB);
+
+		for (inst = 0; inst < a->item_list_sz; inst++) {
+			sprintf(buf, "usb%d", inst);
+			pmiAddInstance(indom, buf, inst);
+		}
+	}
+
+	pmiAddMetric("power.usb.bus",
+		     PM_IN_NULL, PM_TYPE_U32, indom, PM_SEM_DISCRETE,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+
+	pmiAddMetric("power.usb.vendorId",
+		     PM_IN_NULL, PM_TYPE_STRING, indom, PM_SEM_DISCRETE,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+
+	pmiAddMetric("power.usb.productId",
+		     PM_IN_NULL, PM_TYPE_STRING, indom, PM_SEM_DISCRETE,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+
+	pmiAddMetric("power.usb.maxpower",
+		     PM_IN_NULL, PM_TYPE_U32, indom, PM_SEM_DISCRETE,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+
+	pmiAddMetric("power.usb.manufacturer",
+		     PM_IN_NULL, PM_TYPE_STRING, indom, PM_SEM_DISCRETE,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+
+	pmiAddMetric("power.usb.productName",
+		     PM_IN_NULL, PM_TYPE_STRING, indom, PM_SEM_DISCRETE,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+#endif /* HAVE_PCP */
+}
+
+/*
+ ***************************************************************************
+ * Define PCP metrics for filesystem statistics.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ ***************************************************************************
+ */
+void pcp_def_filesystem_metrics(struct activity *a)
+{
+#ifdef HAVE_PCP
+	int inst = 0;
+	static pmInDom indom = PM_INDOM_NULL;
+	struct sa_item *list = a->item_list;
+
+	if (indom == PM_INDOM_NULL) {
+		/* Create domain */
+		indom = pmInDom_build(0, PM_INDOM_FILESYSTEM);
+
+		/* Create instances */
+		while (list != NULL) {
+			pmiAddInstance(indom, list->item_name, inst++);
+			list = list->next;
+		}
+	}
+
+	pmiAddMetric("fs.util.fsfree",
+		     PM_IN_NULL, PM_TYPE_U64, indom, PM_SEM_INSTANT,
+		     pmiUnits(1, 0, 0, PM_SPACE_MBYTE, 0, 0));
+
+	pmiAddMetric("fs.util.fsused",
+		     PM_IN_NULL, PM_TYPE_U64, indom, PM_SEM_INSTANT,
+		     pmiUnits(1, 0, 0, PM_SPACE_MBYTE, 0, 0));
+
+	pmiAddMetric("fs.util.fsused_pct",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+
+	pmiAddMetric("fs.util.ufsused_pct",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+
+	pmiAddMetric("fs.util.ifree",
+		     PM_IN_NULL, PM_TYPE_U64, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, 0, 1, 0, 0, PM_COUNT_ONE));
+
+	pmiAddMetric("fs.util.iused",
+		     PM_IN_NULL, PM_TYPE_U64, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, 0, 1, 0, 0, PM_COUNT_ONE));
+
+	pmiAddMetric("fs.util.iused_pct",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, 0, 0, 0, 0, 0));
+#endif /* HAVE_PCP */
+}
+
+/*
+ ***************************************************************************
+ * Define PCP metrics for Fibre Channel HBA statistics.
+ *
+ * IN:
+ * @a		Activity structure with statistics.
+ ***************************************************************************
+ */
+void pcp_def_fchost_metrics(struct activity *a)
+{
+#ifdef HAVE_PCP
+	int inst = 0;
+	static pmInDom indom = PM_INDOM_NULL;
+	struct sa_item *list = a->item_list;
+
+	if (indom == PM_INDOM_NULL) {
+		/* Create domain */
+		indom = pmInDom_build(0, PM_INDOM_FCHOST);
+
+		/* Create instances */
+		while (list != NULL) {
+			pmiAddInstance(indom, list->item_name, inst++);
+			list = list->next;
+		}
+	}
+
+	pmiAddMetric("network.fchost.in.frame",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, -1, 1, 0, PM_TIME_SEC, PM_COUNT_ONE));
+
+	pmiAddMetric("network.fchost.out.frame",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, -1, 1, 0, PM_TIME_SEC, PM_COUNT_ONE));
+
+	pmiAddMetric("network.fchost.in.word",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, -1, 1, 0, PM_TIME_SEC, PM_COUNT_ONE));
+
+	pmiAddMetric("network.fchost.out.word",
+		     PM_IN_NULL, PM_TYPE_FLOAT, indom, PM_SEM_INSTANT,
+		     pmiUnits(0, -1, 1, 0, PM_TIME_SEC, PM_COUNT_ONE));
+#endif /* HAVE_PCP */
+}
