@@ -610,7 +610,8 @@ __print_funct_t pcp_print_disk_stats(struct activity *a, int curr, unsigned long
 		}
 
 		/* Get device name */
-		dev_name = get_sa_devname(sdc->major, sdc->minor, flags);
+		dev_name = get_sa_devname(sdc->major, sdc->minor,
+					  sdc->wwn, sdc->part_nr, flags);
 
 		if (a->item_list != NULL) {
 			/* A list of devices has been entered on the command line */
@@ -2185,16 +2186,17 @@ __print_funct_t pcp_print_fchost_stats(struct activity *a, int curr, unsigned lo
 {
 #ifdef HAVE_PCP
 	int i, j, j0, found;
-	struct stats_fchost *sfcc, *sfcp;
+	struct stats_fchost *sfcc, *sfcp, sfczero;
 	char buf[64];
 
+	memset(&sfczero, 0, sizeof(struct stats_fchost));
+
 	for (i = 0; i < a->nr[curr]; i++) {
 
 		found = FALSE;
+		sfcc = (struct stats_fchost *) ((char *) a->buf[curr] + i * a->msize);
 
 		if (a->nr[!curr] > 0) {
-			sfcc = (struct stats_fchost *) ((char *) a->buf[curr] + i * a->msize);
-
 			/* Look for corresponding structure in previous iteration */
 			j = i;
 
@@ -2217,8 +2219,10 @@ __print_funct_t pcp_print_fchost_stats(struct activity *a, int curr, unsigned lo
 			while (j != j0);
 		}
 
-		if (!found)
-			continue;
+		if (!found) {
+			/* This is a newly registered host */
+			sfcp = &sfczero;
+		}
 
 		snprintf(buf, sizeof(buf), "%f",
 			 S_VALUE(sfcp->f_rxframes, sfcc->f_rxframes, itv));
