@@ -537,7 +537,8 @@ __print_funct_t raw_print_disk_stats(struct activity *a, char *timestr, int curr
 		sdc = (struct stats_disk *) ((char *) a->buf[curr] + i * a->msize);
 
 		/* Get device name */
-		dev_name = get_sa_devname(sdc->major, sdc->minor, flags);
+		dev_name = get_sa_devname(sdc->major, sdc->minor,
+					  sdc->wwn, sdc->part_nr, flags);
 
 		if (a->item_list != NULL) {
 			/* A list of devices has been entered on the command line */
