@@ -244,6 +244,10 @@ int set_default_file(char *datafile, int d_off, int sa_name)
 	datafile[MAX_FILE_LEN - 1] = '\0';
 	default_file_used = TRUE;
 
+#ifdef DEBUG
+	fprintf(stderr, "%s: Datafile: %s\n", __FUNCTION__, datafile);
+#endif
+
 	return ((err < 0) || (err >= MAX_FILE_LEN));
 }
 
@@ -817,7 +821,7 @@ void get_itv_value(struct record_header *record_hdr_curr,
  * 		not the time, should be used by the caller.
  ***************************************************************************
  */
-void get_file_timestamp_struct(unsigned int flags, struct tm *rectime,
+void get_file_timestamp_struct(uint64_t flags, struct tm *rectime,
 			       struct file_header *file_hdr)
 {
 	if (PRINT_TRUE_TIME(flags)) {
@@ -851,7 +855,7 @@ void get_file_timestamp_struct(unsigned int flags, struct tm *rectime,
  * @rectime	Date and time from file header.
  ***************************************************************************
  */
-void print_report_hdr(unsigned int flags, struct tm *rectime,
+void print_report_hdr(uint64_t flags, struct tm *rectime,
 		      struct file_header *file_hdr)
 {
 
@@ -1526,6 +1530,7 @@ int skip_extra_struct(int ifd, int endian_mismatch, int arch_64)
  * @oneof	Set to EOF_CONT if an unexpected end of file should not make
  *		sadf stop. Default behavior is to stop on unexpected EOF.
  * @b_size	@buffer size.
+ * @flags	Flags for common options and system state.
  *
  * OUT:
  * @record_hdr	Record header for current sample.
@@ -1538,7 +1543,7 @@ int skip_extra_struct(int ifd, int endian_mismatch, int arch_64)
  */
 int read_record_hdr(int ifd, void *buffer, struct record_header *record_hdr,
 		    struct file_header *file_hdr, int arch_64, int endian_mismatch,
-		    int oneof, size_t b_size)
+		    int oneof, size_t b_size, uint64_t flags)
 {
 	int rc;
 
@@ -1558,6 +1563,14 @@ int read_record_hdr(int ifd, void *buffer, struct record_header *record_hdr,
 			swap_struct(rec_types_nr, record_hdr, arch_64);
 		}
 
+		/* Raw output in debug mode */
+		if (DISPLAY_DEBUG_MODE(flags)) {
+			printf("# uptime_cs; %llu; ust_time; %llu; extra_next; %u; record_type; %d; HH:MM:SS; %02d:%02d:%02d\n",
+			       record_hdr->uptime_cs, record_hdr->ust_time,
+			       record_hdr->extra_next, record_hdr->record_type,
+			       record_hdr->hour, record_hdr->minute, record_hdr->second);
+		}
+
 		/*
 		 * Skip unknown extra structures if present.
 		 * This will be done later for R_COMMENT and R_RESTART records, as extra structures
@@ -1866,8 +1879,7 @@ int sa_open_read_magic(int *fd, char *dfile, struct file_magic *file_magic,
 	    ((file_magic->sysstat_version == 10) && (file_magic->sysstat_patchlevel >= 3))) {
 		/* header_size field exists only for sysstat versions 10.3.1 and later */
 		if ((file_magic->header_size <= MIN_FILE_HEADER_SIZE) ||
-		    (file_magic->header_size > MAX_FILE_HEADER_SIZE) ||
-		    ((file_magic->header_size < FILE_HEADER_SIZE) && !ignore)) {
+		    (file_magic->header_size > MAX_FILE_HEADER_SIZE)) {
 #ifdef DEBUG
 			fprintf(stderr, "%s: header_size=%u\n",
 				__FUNCTION__, file_magic->header_size);
@@ -1926,7 +1938,7 @@ int sa_open_read_magic(int *fd, char *dfile, struct file_magic *file_magic,
  * @arch_64	TRUE if file's data come from a 64 bit machine.
  ***************************************************************************
  */
-void check_file_actlst(int *ifd, char *dfile, struct activity *act[], unsigned int flags,
+void check_file_actlst(int *ifd, char *dfile, struct activity *act[], uint64_t flags,
 		       struct file_magic *file_magic, struct file_header *file_hdr,
 		       struct file_activity **file_actlst, unsigned int id_seq[],
 		       int ignore, int *endian_mismatch, int *arch_64)
@@ -1934,6 +1946,8 @@ void check_file_actlst(int *ifd, char *dfile, struct activity *act[], unsigned i
 	int i, j, k, p;
 	struct file_activity *fal;
 	void *buffer = NULL;
+	size_t bh_size = FILE_HEADER_SIZE;
+	size_t ba_size = FILE_ACTIVITY_SIZE;
 
 	/* Open sa data file and read its magic structure */
 	if (sa_open_read_magic(ifd, dfile, file_magic, ignore, endian_mismatch, TRUE) < 0)
@@ -1960,17 +1974,20 @@ void check_file_actlst(int *ifd, char *dfile, struct activity *act[], unsigned i
 	}
 
 	/* Allocate buffer for file_header structure */
-	SREALLOC(buffer, char, file_magic->header_size);
+	if (file_magic->header_size > FILE_HEADER_SIZE) {
+		bh_size = file_magic->header_size;
+	}
+	SREALLOC(buffer, char, bh_size);
 
 	/* Read sa data file standard header and allocate activity list */
 	sa_fread(*ifd, buffer, (size_t) file_magic->header_size, HARD_SIZE, UEOF_STOP);
 	/*
 	 * Data file header size (file_magic->header_size) may be greater or
 	 * smaller than FILE_HEADER_SIZE. Remap the fields of the file header
-	 * then copy its contents to the expected  structure.
+	 * then copy its contents to the expected structure.
 	 */
 	if (remap_struct(hdr_types_nr, file_magic->hdr_types_nr, buffer,
-			 file_magic->header_size, FILE_HEADER_SIZE, file_magic->header_size) < 0)
+			 file_magic->header_size, FILE_HEADER_SIZE, bh_size) < 0)
 		goto format_error;
 
 	memcpy(file_hdr, buffer, FILE_HEADER_SIZE);
@@ -2005,7 +2022,11 @@ void check_file_actlst(int *ifd, char *dfile, struct activity *act[], unsigned i
 		goto format_error;
 	}
 
-	SREALLOC(buffer, char, file_hdr->act_size);
+	/* Allocate buffer for file_activity structures */
+	if (file_hdr->act_size > FILE_ACTIVITY_SIZE) {
+		ba_size = file_hdr->act_size;
+	}
+	SREALLOC(buffer, char, ba_size);
 	SREALLOC(*file_actlst, struct file_activity, FILE_ACTIVITY_SIZE * file_hdr->sa_act_nr);
 	fal = *file_actlst;
 
@@ -2021,7 +2042,7 @@ void check_file_actlst(int *ifd, char *dfile, struct activity *act[], unsigned i
 		* then copy its contents to the expected structure.
 		*/
 		if (remap_struct(act_types_nr, file_hdr->act_types_nr, buffer,
-			     file_hdr->act_size, FILE_ACTIVITY_SIZE, file_hdr->act_size) < 0)
+			     file_hdr->act_size, FILE_ACTIVITY_SIZE, ba_size) < 0)
 			goto format_error;
 		memcpy(fal, buffer, FILE_ACTIVITY_SIZE);
 
@@ -2196,7 +2217,7 @@ format_error:
  ***************************************************************************
  */
 int parse_sar_opt(char *argv[], int *opt, struct activity *act[],
-		  unsigned int *flags, int caller)
+		  uint64_t *flags, int caller)
 {
 	int i, p;
 
@@ -2561,7 +2582,7 @@ int parse_sar_n_opt(char *argv[], int *opt, struct activity *act[])
  * 0 on success, 1 otherwise.
  ***************************************************************************
  */
-int parse_sar_I_opt(char *argv[], int *opt, unsigned int *flags, struct activity *act[])
+int parse_sar_I_opt(char *argv[], int *opt, uint64_t *flags, struct activity *act[])
 {
 	int p;
 
@@ -2598,7 +2619,7 @@ int parse_sar_I_opt(char *argv[], int *opt, unsigned int *flags, struct activity
  * 0 on success, 1 otherwise.
  ***************************************************************************
  */
-int parse_sa_P_opt(char *argv[], int *opt, unsigned int *flags, struct activity *act[])
+int parse_sa_P_opt(char *argv[], int *opt, uint64_t *flags, struct activity *act[])
 {
 	int p;
 
@@ -2628,7 +2649,7 @@ int parse_sa_P_opt(char *argv[], int *opt, unsigned int *flags, struct activity
  * @act		Array of selected activities.
  ***************************************************************************
  */
-void set_bitmaps(struct activity *act[], unsigned int *flags)
+void set_bitmaps(struct activity *act[], uint64_t *flags)
 {
 	int p;
 
@@ -2869,7 +2890,7 @@ void replace_nonprintable_char(int ifd, char *comment)
  * 1 if an error was detected, or 0 otherwise.
  ***************************************************************************
 */
-int sa_get_record_timestamp_struct(unsigned int l_flags, struct record_header *record_hdr,
+int sa_get_record_timestamp_struct(uint64_t l_flags, struct record_header *record_hdr,
 				   struct tm *rectime)
 {
 	struct tm *ltm;
@@ -2929,7 +2950,7 @@ int sa_get_record_timestamp_struct(unsigned int l_flags, struct record_header *r
  * 		been used.
  ***************************************************************************
 */
-void set_record_timestamp_string(unsigned int l_flags, struct record_header *record_hdr,
+void set_record_timestamp_string(uint64_t l_flags, struct record_header *record_hdr,
 				 char *cur_date, char *cur_time, int len, struct tm *rectime)
 {
 	/* Set cur_time date value */
@@ -2987,7 +3008,7 @@ void set_record_timestamp_string(unsigned int l_flags, struct record_header *rec
  * 1 if the record has been successfully displayed, and 0 otherwise.
  ***************************************************************************
  */
-int print_special_record(struct record_header *record_hdr, unsigned int l_flags,
+int print_special_record(struct record_header *record_hdr, uint64_t l_flags,
 			 struct tstamp *tm_start, struct tstamp *tm_end, int rtype, int ifd,
 			 struct tm *rectime, char *file, int tab,
 			 struct file_magic *file_magic, struct file_header *file_hdr,
@@ -3098,7 +3119,7 @@ int print_special_record(struct record_header *record_hdr, unsigned int l_flags,
  ***************************************************************************
  */
 unsigned long long get_global_cpu_statistics(struct activity *a, int prev, int curr,
-					     unsigned int flags, unsigned char offline_cpu_bitmap[])
+					     uint64_t flags, unsigned char offline_cpu_bitmap[])
 {
 	int i;
 	unsigned long long tot_jiffies_c, tot_jiffies_p;
@@ -3245,7 +3266,7 @@ unsigned long long get_global_cpu_statistics(struct activity *a, int prev, int c
  ***************************************************************************
  */
 void get_global_soft_statistics(struct activity *a, int prev, int curr,
-				unsigned int flags, unsigned char offline_cpu_bitmap[])
+				uint64_t flags, unsigned char offline_cpu_bitmap[])
 {
 	int i;
 	struct stats_softnet *ssnc, *ssnp;
@@ -3315,7 +3336,7 @@ void get_global_soft_statistics(struct activity *a, int prev, int curr,
  ***************************************************************************
  */
 char *get_sa_devname(unsigned int major, unsigned int minor, unsigned long long wwn[],
-		     unsigned int part_nr, unsigned int flags)
+		     unsigned int part_nr, uint64_t flags)
 {
 	char *dev_name = NULL, *persist_dev_name = NULL;
 	static char sid[64];
