@@ -22,6 +22,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <stdint.h>
 #include <ctype.h>
 #include <unistd.h>
 #include <fcntl.h>
@@ -56,10 +57,13 @@ char *sccsid(void) { return (SCCSID); }
 
 #ifdef TEST
 extern time_t __unix_time;
+extern int __env;
 #endif
 
+extern char *tzname[2];
+
 long interval = 0;
-unsigned int flags = 0;
+uint64_t flags = 0;
 
 int optz = 0;
 char timestamp[2][TIMESTAMP_LEN];
@@ -517,6 +521,11 @@ void setup_file_hdr(int fd)
 	strncpy(file_hdr.sa_machine, header.machine, UTSNAME_LEN);
 	file_hdr.sa_machine[UTSNAME_LEN - 1]  = '\0';
 
+	/* Get timezone value and save it */
+	tzset();
+	strncpy(file_hdr.sa_tzname, tzname[0], TZNAME_LEN);
+	file_hdr.sa_tzname[TZNAME_LEN - 1] = '\0';
+
 	/* Write file header */
 	if (write_all(fd, &file_hdr, FILE_HEADER_SIZE) != FILE_HEADER_SIZE) {
 		p_write_error();
@@ -1035,7 +1044,7 @@ void rw_sa_stat_loop(long count, int stdfd, int ofd, char ofile[],
 		     char sa_dir[])
 {
 	int do_sa_rotat = 0;
-	unsigned int save_flags;
+	uint64_t save_flags;
 	char new_ofile[MAX_FILE_LEN] = "";
 	struct tm rectime = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL};
 
@@ -1244,6 +1253,10 @@ int main(int argc, char **argv)
 		}
 
 #ifdef TEST
+		else if (!strncmp(argv[opt], "--getenv", 8)) {
+			__env = TRUE;
+		}
+
 		else if (!strncmp(argv[opt], "--unix_time=", 12)) {
 			if (strspn(argv[opt] + 12, DIGITS) != strlen(argv[opt] + 12)) {
 				usage(argv[0]);
