@@ -22,6 +22,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <stdint.h>
 #include <stdarg.h>
 #include <unistd.h>
 #include <time.h>
@@ -49,6 +50,7 @@ char *sccsid(void) { return (SCCSID); }
 #endif
 
 #ifdef TEST
+extern int __env;
 void int_handler(int n) { return; }
 #endif
 
@@ -63,7 +65,7 @@ int dplaces_nr = -1;
 /* Color palette number */
 int palette = SVG_DEFAULT_COL_PALETTE;
 
-unsigned int flags = 0;
+uint64_t flags = 0;
 unsigned int dm_major;		/* Device-mapper major number */
 unsigned int format = 0;	/* Output format */
 unsigned int f_position = 0;	/* Output format position in array */
@@ -240,7 +242,7 @@ int read_next_sample(int ifd, int action, int curr, char *file, int *rtype, int
 
 	/* Read current record */
 	if ((rc = read_record_hdr(ifd, rec_hdr_tmp, &record_hdr[curr], &file_hdr,
-			    arch_64, endian_mismatch, oneof, sizeof(rec_hdr_tmp))) != 0)
+			    arch_64, endian_mismatch, oneof, sizeof(rec_hdr_tmp), flags)) != 0)
 		/* End of sa file */
 		return rc;
 
@@ -749,7 +751,7 @@ int generic_write_stats(int curr, int use_tm_start, int use_tm_end, int reset,
 			else if (format == F_RAW_OUTPUT) {
 				/* Raw output */
 				if (DISPLAY_DEBUG_MODE(flags)) {
-					printf("# %s: %d/%d (%d)\n", act[i]->name,
+					printf("# name; %s; nr_curr; %d; nr_alloc; %d; nr_ini; %d\n", act[i]->name,
 					       act[i]->nr[curr], act[i]->nr_allocated, act[i]->nr_ini);
 				}
 
@@ -1568,6 +1570,13 @@ int main(int argc, char **argv)
 			}
 		}
 
+#ifdef TEST
+		else if (!strncmp(argv[opt], "--getenv", 8)) {
+			__env = TRUE;
+			opt++;
+		}
+#endif
+
 		else if (!strcmp(argv[opt], "-O")) {
 			/* Parse output options */
 			if (!argv[++opt] || sar_options) {
