@@ -22,6 +22,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <stdint.h>
 #include <unistd.h>
 #include <time.h>
 #include <errno.h>
@@ -46,6 +47,7 @@ char *sccsid(void) { return (SCCSID); }
 
 #ifdef TEST
 extern time_t __unix_time;
+extern int __env;
 #endif
 
 /* Interval and count parameters */
@@ -60,7 +62,7 @@ int arch_64 = FALSE;
 /* Number of decimal places */
 int dplaces_nr = -1;
 
-unsigned int flags = 0;
+uint64_t flags = 0;
 unsigned int dm_major;	/* Device-mapper major number */
 
 char timestamp[2][TIMESTAMP_LEN];
@@ -780,7 +782,7 @@ void handle_curr_act_stats(int ifd, off_t fpos, int *curr, long *cnt, int *eosaf
 		 * Start with reading current sample's record header.
 		 */
 		*eosaf = read_record_hdr(ifd, rec_hdr_tmp, &record_hdr[*curr],
-					 &file_hdr, arch_64, endian_mismatch, UEOF_STOP, b_size);
+					 &file_hdr, arch_64, endian_mismatch, UEOF_STOP, b_size, flags);
 		rtype = record_hdr[*curr].record_type;
 
 		if (!*eosaf && (rtype != R_RESTART) && (rtype != R_COMMENT)) {
@@ -1015,7 +1017,7 @@ void read_stats_from_file(char from_file[])
 		 */
 		do {
 			if (read_record_hdr(ifd, rec_hdr_tmp, &record_hdr[0], &file_hdr,
-					    arch_64, endian_mismatch, UEOF_STOP, sizeof(rec_hdr_tmp))) {
+					    arch_64, endian_mismatch, UEOF_STOP, sizeof(rec_hdr_tmp), flags)) {
 				/* End of sa data file */
 				return;
 			}
@@ -1113,7 +1115,7 @@ void read_stats_from_file(char from_file[])
 			do {
 				/* Read next record header */
 				eosaf = read_record_hdr(ifd, rec_hdr_tmp, &record_hdr[curr],
-							&file_hdr, arch_64, endian_mismatch, UEOF_STOP, sizeof(rec_hdr_tmp));
+							&file_hdr, arch_64, endian_mismatch, UEOF_STOP, sizeof(rec_hdr_tmp), flags);
 				rtype = record_hdr[curr].record_type;
 
 				if (!eosaf && (rtype != R_RESTART) && (rtype != R_COMMENT)) {
@@ -1274,9 +1276,6 @@ int main(int argc, char **argv)
 	init_nls();
 #endif
 
-	/* Init color strings */
-	init_colors();
-
 	tm_start.use = tm_end.use = FALSE;
 
 	/* Allocate and init activity bitmaps */
@@ -1434,6 +1433,11 @@ int main(int argc, char **argv)
 		}
 
 #ifdef TEST
+		else if (!strncmp(argv[opt], "--getenv", 8)) {
+			__env = TRUE;
+			opt++;
+		}
+
 		else if (!strncmp(argv[opt], "--unix_time=", 12)) {
 			if (strspn(argv[opt] + 12, DIGITS) != strlen(argv[opt] + 12)) {
 				usage(argv[0]);
@@ -1491,6 +1495,9 @@ int main(int argc, char **argv)
 		}
 	}
 
+	/* Init color strings */
+	init_colors();
+
 	/* 'sar' is equivalent to 'sar -f' */
 	if ((argc == 1) ||
 	    (((interval < 0) || INTERVAL_SET(flags)) && !from_file[0] && !to_file[0])) {
